@@ -1,10 +1,36 @@
 """
-time_str
-====================================
-A package to convert strings to datetime.timedelta objects
+********
+Time_str
+********
+
+A package to convert user input into datetime.timedelta objects.
+
+PyPI: https://pypi.org/project/time-str/
+
+Docs: https://time-str.readthedocs.io/en/latest/
+
+Installation
+############
+
+You can install released versions of time_str from the Python Package Index via pip or a similar tool:
+
+**Stable Release:** ``pip install time_str``
+
+**Working Version:** ``pip install git+https://github.com/BobDotCom/time_str.git``
+
+Usage
+#####
+.. code-block:: python
+
+    >>> import time_str
+    >>> time_str.convert('11 months 9days 1m 3 sec')
+    datetime.timedelta(days=345, seconds=63)
+    >>> time_str.convert('2 months 3w 1 d 5hour 3 min')
+    datetime.timedelta(days=83, seconds=18180)
 """
 
-import datetime, re
+import datetime
+import re
 
 
 class Converter:
@@ -62,7 +88,10 @@ class Converter:
                     to_add = entry.replace(form,'')
                     if to_add.replace('.','').isdigit():
                         self.raw_output[form] += float(to_add)
-        self.raw_output['days'] += 31 * self.raw_output['months'] # datetime.timedelta does not support months
+        if self.raw_output['months'] > 12:
+            self.raw_output['years'] += self.raw_output['months'] // 12
+            self.raw_output['months'] %= 12
+        self.raw_output['days'] += round(30.5 * self.raw_output['months']) # datetime.timedelta does not support months
         self.raw_output['days'] += 365 * self.raw_output['years'] # datetime.timedelta does not support years
         self.output = datetime.timedelta(seconds=self.raw_output['seconds'], minutes=self.raw_output['minutes'], hours=self.raw_output['hours'], days=self.raw_output['days'], weeks=self.raw_output['weeks'])
         return self.output
@@ -86,5 +115,5 @@ def convert(input_string: str):
 
 
 __author__='BobDotCom'
-__version__='0.0.2'
+__version__='0.0.3post1'
 
